Class: Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1BasicLevel
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1BasicLevel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1p7beta1/classes.rb,
lib/google/apis/cloudasset_v1p7beta1/representations.rb,
lib/google/apis/cloudasset_v1p7beta1/representations.rb
Overview
BasicLevel is an AccessLevel using a set of recommended features.
Instance Attribute Summary collapse
-
#combining_function ⇒ String
How the
conditionslist should be combined to determine if a request is granted thisAccessLevel. -
#conditions ⇒ Array<Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1Condition>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1BasicLevel
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1BasicLevel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1BasicLevel
Returns a new instance of GoogleIdentityAccesscontextmanagerV1BasicLevel.
1284 1285 1286 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#combining_function ⇒ String
How the conditions list should be combined to determine if a request is
granted this AccessLevel. If AND is used, each Condition in conditions
must be satisfied for the AccessLevel to be applied. If OR is used, at least
one Condition in conditions must be satisfied for the AccessLevel to be
applied. Default behavior is AND.
Corresponds to the JSON property combiningFunction
1277 1278 1279 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1277 def combining_function @combining_function end |
#conditions ⇒ Array<Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1Condition>
Required. A list of requirements for the AccessLevel to be granted.
Corresponds to the JSON property conditions
1282 1283 1284 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1282 def conditions @conditions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1289 1290 1291 1292 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1289 def update!(**args) @combining_function = args[:combining_function] if args.key?(:combining_function) @conditions = args[:conditions] if args.key?(:conditions) end |