Class: Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1IngressFrom
- Inherits:
-
Object
- Object
- Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1IngressFrom
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/cloudasset_v1p7beta1/classes.rb,
lib/google/apis/cloudasset_v1p7beta1/representations.rb,
lib/google/apis/cloudasset_v1p7beta1/representations.rb
Overview
Defines the conditions under which an IngressPolicy matches a request.
Conditions are based on information about the source of the request. The
request must satisfy what is defined in sources AND identity related fields
in order to match.
Instance Attribute Summary collapse
-
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
-
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the perimeter.
-
#sources ⇒ Array<Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1IngressSource>
Sources that this IngressPolicy authorizes access from.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom
constructor
A new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressFrom
Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressFrom.
1702 1703 1704 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1702 def initialize(**args) update!(**args) end |
Instance Attribute Details
#identities ⇒ Array<String>
A list of identities that are allowed access through [IngressPolicy].
Identities can be an individual user, service account, Google group, third-
party identity, or agent identity. For the list of supported identity types,
see https://docs.cloud.google.com/vpc-service-controls/docs/supported-
identities.
Corresponds to the JSON property identities
1688 1689 1690 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1688 def identities @identities end |
#identity_type ⇒ String
Specifies the type of identities that are allowed access from outside the
perimeter. If left unspecified, then members of identities field will be
allowed access.
Corresponds to the JSON property identityType
1695 1696 1697 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1695 def identity_type @identity_type end |
#sources ⇒ Array<Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1IngressSource>
Sources that this IngressPolicy authorizes access from.
Corresponds to the JSON property sources
1700 1701 1702 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1700 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1707 1708 1709 1710 1711 |
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1707 def update!(**args) @identities = args[:identities] if args.key?(:identities) @identity_type = args[:identity_type] if args.key?(:identity_type) @sources = args[:sources] if args.key?(:sources) end |