Class: Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1IngressTo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/cloudasset_v1p7beta1/classes.rb,
lib/google/apis/cloudasset_v1p7beta1/representations.rb,
lib/google/apis/cloudasset_v1p7beta1/representations.rb

Overview

Defines the conditions under which an IngressPolicy matches a request. Conditions are based on information about the ApiOperation intended to be performed on the target resource of the request. The request must satisfy what is defined in operations AND resources in order to match.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIdentityAccesscontextmanagerV1IngressTo

Returns a new instance of GoogleIdentityAccesscontextmanagerV1IngressTo.



1797
1798
1799
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationsArray<Google::Apis::CloudassetV1p7beta1::GoogleIdentityAccesscontextmanagerV1ApiOperation>

A list of ApiOperations allowed to be performed by the sources specified in corresponding IngressFrom in this ServicePerimeter. Corresponds to the JSON property operations



1781
1782
1783
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1781

def operations
  @operations
end

#resourcesArray<String>

A list of resources, currently only projects in the form projects/, protected by this ServicePerimeter that are allowed to be accessed by sources defined in the corresponding IngressFrom. If a single * is specified, then access to all resources inside the perimeter are allowed. Corresponds to the JSON property resources

Returns:

  • (Array<String>)


1789
1790
1791
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1789

def resources
  @resources
end

#rolesArray<String>

IAM roles that represent the set of operations that the sources specified in the corresponding IngressFrom are allowed to perform in this ServicePerimeter. Corresponds to the JSON property roles

Returns:

  • (Array<String>)


1795
1796
1797
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1795

def roles
  @roles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1802
1803
1804
1805
1806
# File 'lib/google/apis/cloudasset_v1p7beta1/classes.rb', line 1802

def update!(**args)
  @operations = args[:operations] if args.key?(:operations)
  @resources = args[:resources] if args.key?(:resources)
  @roles = args[:roles] if args.key?(:roles)
end